pub struct RpcEnvelope {
pub route_key: String,
pub payload: Option<Bytes>,
pub error: Option<ErrorResponse>,
pub direction: Option<i32>,
pub traceparent: Option<String>,
pub tracestate: Option<String>,
pub request_id: String,
pub metadata: Vec<MetadataEntry>,
pub timeout_ms: i64,
}Expand description
RpcEnvelope wraps State Path RPC messages
Fields
route_key: StringRoute key: “package.Service.Method”
payload: Option<Bytes>Payload for successful RPC (request or response) Optional: when error is present, payload should be empty
error: Option<ErrorResponse>System-level error (envelope layer) Examples: UnknownRoute, DeserializationError, Panic, InvalidStateTransition Business errors should be in the response message payload
direction: Option<i32>Envelope direction: Request or Response. See Direction above.
traceparent: Option<String>W3C trace context header values (for distributed tracing)
W3C trace context header value
tracestate: Option<String>W3C trace state header value
request_id: Stringmetadata: Vec<MetadataEntry>timeout_ms: i64Implementations
Sourceimpl RpcEnvelope
impl RpcEnvelope
Sourcepub fn payload(&self) -> &[u8] ⓘ
pub fn payload(&self) -> &[u8] ⓘ
Returns the value of payload, or the default value if payload is unset.
Sourcepub fn direction(&self) -> Direction
pub fn direction(&self) -> Direction
Returns the enum value of direction, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_direction(&mut self, value: Direction)
pub fn set_direction(&mut self, value: Direction)
Sets direction to the provided enum value.
Sourcepub fn traceparent(&self) -> &str
pub fn traceparent(&self) -> &str
Returns the value of traceparent, or the default value if traceparent is unset.
Sourcepub fn tracestate(&self) -> &str
pub fn tracestate(&self) -> &str
Returns the value of tracestate, or the default value if tracestate is unset.