Module acl

Module acl 

ACL (Access Control List) permission checking

Starting from the caller_id of an inbound message and the target actor_id, determines whether the call is permitted based on configured ACL rules. This module is pure functions with no IO dependencies, suitable for both native and wasm32 targets.

Functions

check_acl_permission
Check whether the caller has permission to access the target Actor